aboutsummaryrefslogtreecommitdiff
path: root/ftp/curl/files
diff options
context:
space:
mode:
authorPeter Pentchev <roam@FreeBSD.org>2004-06-03 22:41:40 +0000
committerPeter Pentchev <roam@FreeBSD.org>2004-06-03 22:41:40 +0000
commit64b64d5ff70dae7baae7d1c4985bfe485e310ca3 (patch)
tree3ba02a3613025d14be6bb631b3d27f3f9746aa88 /ftp/curl/files
parent1809887ddd6fd017f42ca369f650921e08b5e991 (diff)
Notes
Diffstat (limited to 'ftp/curl/files')
-rw-r--r--ftp/curl/files/patch-lib::hostip.c16
-rw-r--r--ftp/curl/files/patch-lib::url.c18
2 files changed, 9 insertions, 25 deletions
diff --git a/ftp/curl/files/patch-lib::hostip.c b/ftp/curl/files/patch-lib::hostip.c
deleted file mode 100644
index 4c15c91a7222..000000000000
--- a/ftp/curl/files/patch-lib::hostip.c
+++ /dev/null
@@ -1,16 +0,0 @@
---- lib/hostip.c.orig Fri Apr 9 14:28:07 2004
-+++ lib/hostip.c Fri Apr 9 14:29:12 2004
-@@ -887,11 +887,11 @@
-
- /* now, shrink the allocated buffer to the size we actually need, which
- most often is only a fraction of the original alloc */
-- newbuf=(char *)realloc(*buf, (long)bufptr-(long)(*buf));
-+ newbuf=(char *)realloc(*buf, (long)(bufptr-*buf));
-
- /* if the alloc moved, we need to adjust things again */
- if(newbuf != *buf)
-- hostcache_fixoffset((struct hostent*)newbuf, (long)newbuf-(long)*buf);
-+ hostcache_fixoffset((struct hostent*)newbuf, (long)(newbuf-*buf));
-
- /* setup the return */
- *buf = newbuf;
diff --git a/ftp/curl/files/patch-lib::url.c b/ftp/curl/files/patch-lib::url.c
index af8f7e7cbf36..bc19abd1e208 100644
--- a/ftp/curl/files/patch-lib::url.c
+++ b/ftp/curl/files/patch-lib::url.c
@@ -1,13 +1,13 @@
---- lib/url.c.old Wed Nov 27 17:22:24 2002
-+++ lib/url.c Wed Nov 27 17:23:29 2002
-@@ -288,6 +288,10 @@
-
- data->set.proxytype = CURLPROXY_HTTP; /* defaults to HTTP proxy */
+--- lib/url.c.orig Wed Jun 2 14:45:18 2004
++++ lib/url.c Wed Jun 2 14:45:40 2004
+@@ -329,6 +329,10 @@
+ data->set.httpauth = CURLAUTH_BASIC; /* defaults to basic */
+ data->set.proxyauth = CURLAUTH_BASIC; /* defaults to basic */
+#if defined(__FreeBSD_version)
-+ data->set.no_signal = TRUE; /* different handling of signals and threads */
++ data->set.no_signal = TRUE; /* different handling of signals and threads */
+#endif /* __FreeBSD_version */
+
- /* create an array with connection data struct pointers */
- data->state.numconnects = 5; /* hard-coded right now */
- data->state.connects = (struct connectdata **)
+ /* create an array with connection data struct pointers */
+ data->state.numconnects = 5; /* hard-coded right now */
+ data->state.connects = (struct connectdata **)